#!/usr/bin/env python
# -*- mode: python, coding: utf-8 -*-
# sharing.py (modified from EDAMTest.py)
#
# To run (Unix):
#   export PYTHONPATH=lib; python sharing.py myuser mypass
#

import sys
import hashlib
import binascii
import time
import thrift.protocol.TBinaryProtocol as TBinaryProtocol
import thrift.transport.THttpClient as THttpClient
import evernote.edam.userstore.UserStore as UserStore
import evernote.edam.userstore.constants as UserStoreConstants
import evernote.edam.notestore.NoteStore as NoteStore
import evernote.edam.type.ttypes as Types
import evernote.edam.error.ttypes as Errors

if len(sys.argv) < 3:
    print "Arguments:  <username> <password>";
    exit(1)

username = sys.argv[1]
password = sys.argv[2]

#
# NOTE: You must change the consumer key and consumer secret to the 
#       key and secret that you received from Evernote
#       To get an API key, visit http://dev.evernote.com/documentation/cloud/
consumerKey = "edamtest"
consumerSecret = "0123456789abcdef"

evernoteHost = "sandbox.evernote.com"
userStoreUri = "https://" + evernoteHost + "/edam/user"

userStoreHttpClient = THttpClient.THttpClient(userStoreUri)
userStoreProtocol = TBinaryProtocol.TBinaryProtocol(userStoreHttpClient)
userStore = UserStore.Client(userStoreProtocol)

versionOK = userStore.checkVersion("Python EDAMTest",
                                   UserStoreConstants.EDAM_VERSION_MAJOR,
                                   UserStoreConstants.EDAM_VERSION_MINOR)

print "Is my EDAM protocol version up to date? ", str(versionOK)
print ""
if not versionOK:
    exit(1)

# Authenticate the user
try :
    authResult = userStore.authenticate(username, password,
                                        consumerKey, consumerSecret)
except Errors.EDAMUserException as e:
    # See http://www.evernote.com/about/developer/api/ref/UserStore.html#Fn_UserStore_authenticate
    parameter = e.parameter
    errorCode = e.errorCode
    errorText = Errors.EDAMErrorCode._VALUES_TO_NAMES[errorCode]
    
    print "Authentication failed (parameter: " + parameter + " errorCode: " + errorText + ")"
    
    if errorCode == Errors.EDAMErrorCode.INVALID_AUTH:
        if parameter == "consumerKey":
            if consumerKey == "en-edamtest":
                print "You must replace the variables consumerKey and consumerSecret with the values you received from Evernote."
            else:
                print "Your consumer key was not accepted by", evernoteHost
                print "This sample client application requires a client API key. If you requested a web service API key, you must authenticate using OAuth."
            print "If you do not have an API Key from Evernote, you can request one from http://dev.evernote.com/documentation/cloud/"
        elif parameter == "username":
            print "You must authenticate using a username and password from", evernoteHost
            if evernoteHost != "www.evernote.com":
                print "Note that your production Evernote account will not work on", evernoteHost
                print "You must register for a separate test account at https://" + evernoteHost + "/Registration.action"
        elif parameter == "password":
            print "The password that you entered is incorrect"

    print ""
    exit(1)

user = authResult.user
authToken = authResult.authenticationToken
print "Authentication was successful for ", user.username
print "Authentication token = ", authToken
print "shardId = ", user.shardId

noteStoreHttpClient = THttpClient.THttpClient(authResult.noteStoreUrl)
noteStoreProtocol = TBinaryProtocol.TBinaryProtocol(noteStoreHttpClient)
noteStore = NoteStore.Client(noteStoreProtocol)

## 1. 共有用のノート作成
note = Types.Note()
note.title = "共有ノートテスト"
note.content = '<?xml version="1.0" encoding="UTF-8"?>'
note.content += '<!DOCTYPE en-note SYSTEM "http://xml.evernote.com/pub/enml2.dtd">'
note.content += '<en-note>This note is shared.</en-note>'
createdNote = noteStore.createNote(authToken, note)

## 2. 作成したノートの共有
shareKey = noteStore.shareNote(authToken, createdNote.guid)
url = "https://" + evernoteHost + "/shard/" + user.shardId + "/sh/" + createdNote.guid + "/" + shareKey
print "URL = ", url, "\n"


## 3. 公開ノートブックの作成
notebook = Types.Notebook()
notebook.name = "Public notebook"
notebook.published = True
notebook.publishing = Types.Publishing("test", None, False, "Publishing test")
createdNotebook = noteStore.createNotebook(authToken, notebook)
print "notebook: ", createdNotebook

## 4. 共有ノートブックの作成
notebook = Types.Notebook()
notebook.name = "Shared notebook"
createdNotebook = noteStore.createNotebook(authToken, notebook)
print "createdNotebook: ", createdNotebook, "\n"
sharedNotebook = Types.SharedNotebook()
sharedNotebook.notebookGuid = createdNotebook.guid
sharedNotebook.email = "test@example.com"
sharedNotebook.requireLogin = True
sharedNotebook.notebookModifiable = False
createdSharedNotebook = noteStore.createSharedNotebook(authToken, sharedNotebook)
print "createdSharedNotebook: ", createdSharedNotebook, "\n"

## 5. リンクされたノートのリスト表示
linkedNotebooks = noteStore.listLinkedNotebooks(authToken)
print "Found ", len(linkedNotebooks), " linkedNotebooks:"
for linkedNotebook in linkedNotebooks:
    print "  * ", linkedNotebook.shareName
